IScreenCaptureList class abstract

Constructors

IScreenCaptureList()

Properties

channelTag → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
iconSize → NERtcSize
no setter
includeScreen → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbSize → NERtcSize
no setter

Methods

getCount() → int
Gets the number of shareable windows and screens.
getSourceInfo(int index) → NERtcScreenCaptureSourceInfo
Gets information about the specified shareable window or screen.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Releases IScreenCaptureSourceList.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited