NERtcAudioFrameEventCallback class mixin

原始音频帧回调通知

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMixedAudioFrame(dynamic frame) → void
onPlaybackAudioFrameBeforeMixingForPlayStreaming(String streamId, dynamic frame) → void
onPlaybackAudioFrameBeforeMixingWithUserID(int uid, dynamic frame) → void
onPlaybackFrame(dynamic frame) → void
onPlaybackSubStreamAudioFrameBeforeMixingWithUserID(int uid, dynamic frame) → void
onRecordFrame(dynamic frame) → void
onRecordSubStreamAudioFrame(dynamic frame) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited