NERtcAudioFrameEventSink class abstract

Constructors

NERtcAudioFrameEventSink()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMixedAudioFrame(NERtcAudioFrame frame) → void
onPlaybackAudioFrameBeforeMixingForPlayStreaming(String streamId, NERtcAudioFrame frame) → void
onPlaybackAudioFrameBeforeMixingWithUserID(int uid, NERtcAudioFrame frame) → void
onPlaybackFrame(NERtcAudioFrame frame) → void
onPlaybackSubStreamAudioFrameBeforeMixingWithUserID(int uid, NERtcAudioFrame frame) → void
onRecordFrame(NERtcAudioFrame frame) → void
onRecordSubStreamAudioFrame(NERtcAudioFrame frame) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

setup(NERtcAudioFrameEventSink? api, {BinaryMessenger? binaryMessenger}) → void

Constants

codec → const MessageCodec<Object?>