NERtcAudioFrameFormat class

Constructors

NERtcAudioFrameFormat({required int type, required int channels, required int sampleRate, required int bytesPerSample, required int samplesPerChannel})

Properties

bytesPerSample int
getter/setter pair
channels int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
getter/setter pair
samplesPerChannel int
getter/setter pair
type int
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) NERtcAudioFrameFormat