NERtcChannel class abstract

Constructors

NERtcChannel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLiveStreamTask(NERtcLiveStreamTaskInfo taskInfo) → Future<int>
添加房间内推流任务。成功添加后当前用户可以收到该直播流的状态通知。通话中有效。
adjustUserPlaybackSignalVolume(int uid, int volume) → Future<int>
调节本地播放的指定远端用户的信号音量。
enableAudioVolumeIndication(bool enable, int interval, {bool vad = false}) → Future<int>
enableEncryption(bool enable, NERtcEncryptionConfig config) → Future<int>
开启或关闭媒体流加密。
enableLocalAudio(bool enable) → Future<int>
enableLocalData(bool enable) → Future<int>
启用本地数据
enableLocalSubStreamAudio(bool enable) → Future<int>
开启或关闭音频辅流。
enableLocalVideo(bool enable, {int streamType = NERtcVideoStreamType.main}) → Future<int>
enableMediaPub(int mediaType, bool enable) → Future<int>
媒体流发送,暂时仅支持音频 @param mediaType NERtcMediaPubType
enableSpatializer(bool enable, bool applyToTeam) → Future<int>
enableSpatializerRoomEffects(bool enable) → Future<int>
getChannelName(String channelTag) → Future<String>
getConnectionState() → Future<int>
getFeatureSupportedType(NERtcFeatureType featureType) → Future<int>
获取功能支持类型
getScreenCaptureSources(NERtcSize thumbSize, NERtcSize iconSize, bool includeScreen) → IScreenCaptureList?
获得一个可以分享的屏幕和窗口的列表
initSpatializer() → Future<int>
joinChannel(String? token, String channelName, int uid, NERtcJoinChannelOptions? channelOptions) → Future<int>
leaveChannel() → Future<int>
muteLocalAudioStream(bool mute) → Future<int>
muteLocalVideoStream(bool mute, {int streamType = NERtcVideoStreamType.main}) → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseScreenCapture() → int
暂停屏幕共享。
pushExternalVideoFrame(NERtcVideoFrame frame, {int streamType = NERtcVideoStreamType.main}) → Future<int>
推送外部视频帧。
release() → Future<int>
removeEventCallback(NERtcChannelEventCallback callback) → void
removeLiveStreamTask(String taskId) → Future<int>
删除房间内指定推流任务。
removeStatsEventCallback(NERtcStatsEventCallback callback) → void
reportCustomEvent(String eventName, String? customIdentify, Map<String?, Object?>? param) → Future<int>
用户自定义上报事件。
resumeScreenCapture() → int
恢复屏幕共享。
sendData(NERtcDataExternalFrame frame) → Future<int>
sendSEIMsg(String seiMsg, {int streamType = NERtcVideoStreamType.main}) → Future<int>
指定主流或辅流通道发送媒体增强补充信息(SEI)。 在本端推流传输视频流数据同时,发送流媒体补充增强信息来同步一些其他附加信息。
setAudioRecvRange(int audibleDistance, int conversationalDistance, NERtcDistanceRollOffModel rollOffModel) → Future<int>
setAudioSubscribeOnlyBy(List<int>? uidArray) → Future<int>
设置自己的音频只能被房间内指定的人订阅。 默认房间所有其他人都可以订阅自己的音频。
setCameraCaptureConfig(NERtcCameraCaptureConfig captureConfig, {int streamType = NERtcVideoStreamType.main}) → Future<int>
设置本地摄像头的采集偏好等配置。
setChannelProfile(int channelProfile) → Future<int>
setClientRole(int role) → Future<int>
setEventCallback(NERtcChannelEventCallback callback) → void
setExcludeWindowList(List<int> windowLists, int count) → int
设置共享整个屏幕或屏幕指定区域时,需要屏蔽的窗口列表。
setExternalVideoSource(bool enable, {int streamType = NERtcVideoStreamType.main}) → Future<int>
开启或关闭外部视频源数据输入。
setLocalMediaPriority(int priority, bool isPreemptive) → Future<int>
设置本地用户的媒体流优先级。
setLocalPublishFallbackOption(int option) → Future<int>
设置弱网条件下发布的音视频流回退选项。
setLocalVideoConfig(NERtcVideoConfig videoConfig, {int streamType = NERtcVideoStreamType.main}) → Future<int>
setRangeAudioMode(NERtcRangeAudioMode audioMode) → Future<int>
setRangeAudioTeamID(int teamID) → Future<int>
setRemoteHighPriorityAudioStream(bool enabled, int uid, {int streamType}) → Future<int>
设置远端用户音频流的高优先级。 支持在音频自动订阅的情况下,设置某一个远端用户的音频为最高优先级,可以优先听到该用户的音频
setRemoteSubscribeFallbackOption(int option) → Future<int>
设置弱网条件下订阅的音视频流回退选项。
setScreenCaptureMouseCursor(bool captureCursor) → int
在共享屏幕或窗口时,更新是否显示鼠标。
setScreenCaptureSource(NERtcScreenCaptureSourceInfo source, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
设置屏幕分享参数,该方法在屏幕分享过程中调用,用来快速切换采集源。
setSpatializerRenderMode(NERtcSpatializerRenderMode renderMode) → Future<int>
setSpatializerRoomProperty(NERtcSpatializerRoomProperty property) → Future<int>
setStatsEventCallback(NERtcStatsEventCallback callback) → void
setSubscribeAudioAllowlist(List<int> uidList) → Future<int>
设置订阅音频白名单
setSubscribeAudioBlocklist(List<int> uidList, int streamType) → Future<int>
设置订阅音频黑名单 streamType 参考 NERtcAudioStreamType
setVideoStreamLayerCount(int layerCount) → Future<int>
设置视频流层数
startChannelMediaRelay(NERtcChannelMediaRelayConfiguration config) → Future<int>
开始跨房间媒体流转发。
startScreenCapture(NERtcScreenConfig config) → Future<int>
开启屏幕共享。 exclude pc interface.
startScreenCaptureByDisplayId(int displayId, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
开启屏幕共享,共享范围为指定屏幕的指定区域。
startScreenCaptureByScreenRect(NERtcRectangle screenRect, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
开启屏幕共享,共享范围为指定屏幕的指定区域。
startScreenCaptureByWindowId(int windowId, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
通过指定屏幕 ID 开启屏幕共享。
stopChannelMediaRelay() → Future<int>
停止跨房间媒体流转发。
stopScreenCapture() → Future<int>
关闭屏幕共享。
subscribeAllRemoteAudio(bool subscribe) → Future<int>
订阅或取消订阅所有远端用户的音频主流。 (后续加入的用户也同样生效)
subscribeRemoteAudio(int uid, bool subscribe) → Future<int>
subscribeRemoteData(int uid, bool subscribe) → Future<int>
订阅远端数据
subscribeRemoteSubStreamAudio(int uid, bool subscribe) → Future<int>
subscribeRemoteSubVideoStream(int uid, bool subscribe) → Future<int>
subscribeRemoteVideoStream(int uid, int streamType, bool subscribe) → Future<int>
switchCamera() → Future<int>
switchCameraWithPosition(int position) → Future<int>
指定前置/后置摄像头
takeLocalSnapshot(int streamType, String path) → Future<int>
takeRemoteSnapshot(int uid, int streamType, String path) → Future<int>
toString() → String
A string representation of this object.
inherited
updateChannelMediaRelay(NERtcChannelMediaRelayConfiguration config) → Future<int>
更新媒体流转发的目标房间。
updateLiveStreamTask(NERtcLiveStreamTaskInfo taskInfo) → Future<int>
更新房间内指定推流任务。通过此接口可以实现调整指定推流任务的编码参数、画布布局、推流模式等。
updateScreenCaptureParameters(NERtcScreenCaptureParameters captureParams) → int
更新屏幕共享参数。
updateScreenCaptureRegion(NERtcRectangle regionRect) → int
在共享屏幕或窗口时,更新共享的区域。
updateSelfPosition(NERtcPositionInfo positionInfo) → Future<int>

Operators

operator ==(Object other) → bool
The equality operator.
inherited