NERtcDesktopScreenCapture class abstract

Constructors

NERtcDesktopScreenCapture()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getScreenCaptureSources(NERtcSize thumbSize, NERtcSize iconSize, bool includeScreen) → IScreenCaptureList?
获得一个可以分享的屏幕和窗口的列表
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseScreenCapture() → int
暂停屏幕共享。
resumeScreenCapture() → int
恢复屏幕共享。
setExcludeWindowList(List<int> windowLists, int count) → int
设置共享整个屏幕或屏幕指定区域时,需要屏蔽的窗口列表。
setScreenCaptureMouseCursor(bool captureCursor) → int
在共享屏幕或窗口时,更新是否显示鼠标。
setScreenCaptureSource(NERtcScreenCaptureSourceInfo source, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
设置屏幕分享参数,该方法在屏幕分享过程中调用,用来快速切换采集源。
startScreenCaptureByDisplayId(int displayId, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
开启屏幕共享,共享范围为指定屏幕的指定区域。
startScreenCaptureByScreenRect(NERtcRectangle screenRect, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
开启屏幕共享,共享范围为指定屏幕的指定区域。
startScreenCaptureByWindowId(int windowId, NERtcRectangle regionRect, NERtcScreenCaptureParameters captureParams) → int
通过指定屏幕 ID 开启屏幕共享。
stopScreenCapture() → int
关闭屏幕共享。
toString() → String
A string representation of this object.
inherited
updateScreenCaptureParameters(NERtcScreenCaptureParameters captureParams) → int
更新屏幕共享参数。
updateScreenCaptureRegion(NERtcRectangle regionRect) → int
在共享屏幕或窗口时,更新共享的区域。

Operators

operator ==(Object other) → bool
The equality operator.
inherited