NERtcFrameNormalizedRect class

@if English The normalized rectangle of the video frame. @endif @if Chinese 视频帧的归一化矩形。 @endif

Annotations
  • @JsonSerializable.new()

Constructors

NERtcFrameNormalizedRect({required double x, required double y, required double w, required double h})
NERtcFrameNormalizedRect.fromJson(Map<String, dynamic> json)
factory

Properties

h ↔ double
@if English The height of the video frame. @endif @if Chinese 视频帧的高度比例。 @endif
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
w ↔ double
@if English The width of the video frame. @endif @if Chinese 视频帧的宽度比例。 @endif
getter/setter pair
x ↔ double
@if English The left of the video frame. @endif @if Chinese 视频帧的左侧比例。 @endif
getter/setter pair
y ↔ double
@if English The top of the video frame. @endif @if Chinese 视频帧的顶部比例。 @endif
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited