NERtcMultiPathOption class

@if Chinese 多路径参数 @endif

Annotations
  • @JsonSerializable.new()

Constructors

NERtcMultiPathOption({required bool enableMediaMultiPath, NERtcMultiPathMediaMode mediaMode = NERtcMultiPathMediaMode.multiPathMediaModeSwitch, int badRttThreshold = 500, bool redAudioPacket = false, bool redAudioRtxPacket = false, bool redVideoPacket = false, bool redVideoRtxPacket = false})
NERtcMultiPathOption.fromJson(Map<String, dynamic> json)
factory

Properties

badRttThreshold ↔ int
@if Chinese RTT 阈值,单位 ms @endif
getter/setter pair
enableMediaMultiPath ↔ bool
@if Chinese 是否开启多路径 @endif
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mediaMode ↔ NERtcMultiPathMediaMode
@if Chinese 多路径模式 @endif
getter/setter pair
redAudioPacket ↔ bool
@if Chinese 是否开启音频 RED 包 @endif
getter/setter pair
redAudioRtxPacket ↔ bool
@if Chinese 是否开启音频重传包RED @endif
getter/setter pair
redVideoPacket ↔ bool
@if Chinese 是否开启视频 RED 包 @endif
getter/setter pair
redVideoRtxPacket ↔ bool
@if Chinese 是否开启视频重传包RED @endif
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited